ul {
    font-size: 0;
    list-style: none;
    width: 100%;
    padding-left: 0px;
}
ul li {
    display: inline-block;
    width: 24.0%;
    margin: 5px;
}
ul li:hover {
    opacity: 40%;
}
ul li img {
    opacity: 100%;
    width: 100%;
    background: #959595;
}
#options {
    width: 100%;
}
#left {
    width: 50%;
    height: 220px;
    float: left;
}
#right {
    width: 50%;
    height: 220px;
    float: left;
}